/**
 * This file is part of Swapable shared under AGPL-3.0
 * Copyright (C) 2021 Using Blockchain Ltd, Reg No.: 12658136, United Kingdom
 *
 * @package     Swapable
 * @author      Grégory Saive for Using Blockchain Ltd <greg@ubc.digital>
 * @license     AGPL-3.0
 */
import { Deadline, UInt64 } from 'symbol-sdk';
/**
 * @class TransactionParameters
 * @package Swapable
 * @subpackage Models
 * @since v1.0.0
 * @description Model that describes parameters for transactions with digital assets.
 */
export declare class TransactionParameters {
    /**
     * @description The network epoch adjustment (in seconds)
     */
    epochAjustment: number;
    /**
     * @description The transaction deadline
     */
    deadline: Deadline;
    /**
     * @description The transaction maxFee
     */
    maxFeeInt?: number | undefined;
    /**
     * @description The transaction maxFee
     */
    maxFee: UInt64 | undefined;
    /**
     * Construct an execution parameters instance
     *
     * @param {Deadline}            Deadline
     * @param {UInt64|undefined}    maxFee
     */
    constructor(
    /**
     * @description The network epoch adjustment (in seconds)
     */
    epochAjustment?: number, 
    /**
     * @description The transaction deadline
     */
    deadline?: Deadline, 
    /**
     * @description The transaction maxFee
     */
    maxFeeInt?: number | undefined);
}
